==> goods-center-api-1.6.3-20160905.040851-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/PCGFloorDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto;

import java.io.Serializable;

/**
 * 楼层专用,获取平台券并展示
 */
public class PCGFloorDto implements Serializable {

    private static final long serialVersionUID = 3166215642755150169L;

    private Long pcgId;

    private String title;

    private String subtitle;

    private Integer minPrice;

    private Long switches;

    private String interestPrice;

    private String interestDesc;

    private String iconImage;

    private Integer exchangeType;//1：已兑换，2：积分不足，3：已兑完，4：兑换

    private String startDate;

    private String endDate;

    private String backgroundColor;

    private Integer payLoad;

    private Long stock; // 所有批次的剩余库存

    public Long getPcgId() {
        return pcgId;
    }

    public void setPcgId(Long pcgId) {
        this.pcgId = pcgId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getSubtitle() {
        return subtitle;
    }

    public void setSubtitle(String subtitle) {
        this.subtitle = subtitle;
    }

    public Integer getMinPrice() {
        return minPrice;
    }

    public void setMinPrice(Integer minPrice) {
        this.minPrice = minPrice;
    }

    public Long getSwitches() {
        return switches;
    }

    public void setSwitches(Long switches) {
        this.switches = switches;
    }

    public String getInterestPrice() {
        return interestPrice;
    }

    public void setInterestPrice(String interestPrice) {
        this.interestPrice = interestPrice;
    }

    public String getInterestDesc() {
        return interestDesc;
    }

    public void setInterestDesc(String interestDesc) {
        this.interestDesc = interestDesc;
    }

    public String getIconImage() {
        return iconImage;
    }

    public void setIconImage(String iconImage) {
        this.iconImage = iconImage;
    }

    public Integer getExchangeType() {
        return exchangeType;
    }

    public void setExchangeType(Integer exchangeType) {
        this.exchangeType = exchangeType;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public String getBackgroundColor() {
        return backgroundColor;
    }

    public void setBackgroundColor(String backgroundColor) {
        this.backgroundColor = backgroundColor;
    }

    public Integer getPayLoad() {
        return payLoad;
    }

    public void setPayLoad(Integer payLoad) {
        this.payLoad = payLoad;
    }

    public Long getStock() {
        return stock;
    }

    public void setStock(Long stock) {
        this.stock = stock;
    }
}

==> goods-center-api-1.6.7.6-20161021.030822-2-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/PCGFloorDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto;

import java.io.Serializable;

/**
 * 楼层专用,获取平台券并展示
 */
public class PCGFloorDto implements Serializable {

    private static final long serialVersionUID = 3166215642755150169L;

    private Long pcgId;

    private String title;

    private String subtitle;

    private Integer minPrice;

    private Long switches;

    private String interestPrice;

    private String interestDesc;

    private String iconImage;

    private Integer exchangeType;//1：已兑换，2：积分不足，3：已兑完，4：兑换

    private String startDate;

    private String endDate;

    private String backgroundColor;

    private Integer payLoad;

    private Long stock; // 所有批次的剩余库存

    private String thumbnailImage;

    private String detailImage;

    private String buttonText;

    public String getThumbnailImage() {
        return thumbnailImage;
    }

    public void setThumbnailImage(String thumbnailImage) {
        this.thumbnailImage = thumbnailImage;
    }

    public String getDetailImage() {
        return detailImage;
    }

    public void setDetailImage(String detailImage) {
        this.detailImage = detailImage;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public Long getPcgId() {
        return pcgId;
    }

    public void setPcgId(Long pcgId) {
        this.pcgId = pcgId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getSubtitle() {
        return subtitle;
    }

    public void setSubtitle(String subtitle) {
        this.subtitle = subtitle;
    }

    public Integer getMinPrice() {
        return minPrice;
    }

    public void setMinPrice(Integer minPrice) {
        this.minPrice = minPrice;
    }

    public Long getSwitches() {
        return switches;
    }

    public void setSwitches(Long switches) {
        this.switches = switches;
    }

    public String getInterestPrice() {
        return interestPrice;
    }

    public void setInterestPrice(String interestPrice) {
        this.interestPrice = interestPrice;
    }

    public String getInterestDesc() {
        return interestDesc;
    }

    public void setInterestDesc(String interestDesc) {
        this.interestDesc = interestDesc;
    }

    public String getIconImage() {
        return iconImage;
    }

    public void setIconImage(String iconImage) {
        this.iconImage = iconImage;
    }

    public Integer getExchangeType() {
        return exchangeType;
    }

    public void setExchangeType(Integer exchangeType) {
        this.exchangeType = exchangeType;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public String getBackgroundColor() {
        return backgroundColor;
    }

    public void setBackgroundColor(String backgroundColor) {
        this.backgroundColor = backgroundColor;
    }

    public Integer getPayLoad() {
        return payLoad;
    }

    public void setPayLoad(Integer payLoad) {
        this.payLoad = payLoad;
    }

    public Long getStock() {
        return stock;
    }

    public void setStock(Long stock) {
        this.stock = stock;
    }
}
